require "import"
import "java.text.SimpleDateFormat"
import "java.util.Date"
import "android.content.Context"
import "android.content.Intent"
import "android.content.IntentFilter"
import "android.os.BatteryManager"
import "android.os.Environment"
import "android.os.StatFs"
import "android.provider.Settings"
import "android.os.Build"
import "android.bluetooth.BluetoothAdapter"
import "android.location.LocationManager"

---Dapatkan waktu saat ini
local formattedTime = SimpleDateFormat("hh:mm a").format(Date())

---Dapatkan tanggal sekarang
local formattedDate = SimpleDateFormat("MMMM dd, yyyy").format(Date())

---Dapatkan level baterai
local batteryIntent = this.registerReceiver(nil, IntentFilter(Intent.ACTION_BATTERY_CHANGED))
local level = batteryIntent.getIntExtra(BatteryManager.EXTRA_LEVEL, -1)
local scale = batteryIntent.getIntExtra(BatteryManager.EXTRA_SCALE, -1)
local batteryPercent = (level / scale) * 100

---Dapatkan kesehatan baterai
local health = batteryIntent.getIntExtra(BatteryManager.EXTRA_HEALTH, -1)
local batteryHealth = "Unknown"
if health == BatteryManager.BATTERY_HEALTH_GOOD then
    batteryHealth = "Cukup baik"
elseif health == BatteryManager.BATTERY_HEALTH_OVERHEAT then
    batteryHealth = "Overheat"
elseif health == BatteryManager.BATTERY_HEALTH_DEAD then
    batteryHealth = "Dead"
elseif health == BatteryManager.BATTERY_HEALTH_OVER_VOLTAGE then
    batteryHealth = "Over Voltage"
elseif health == BatteryManager.BATTERY_HEALTH_UNSPECIFIED_FAILURE then
    batteryHealth = "Unspecified Failure"
elseif health == BatteryManager.BATTERY_HEALTH_COLD then
    batteryHealth = "Cold"
end

---Dapatkan status pengisian daya
local status = batteryIntent.getIntExtra(BatteryManager.EXTRA_STATUS, -1)
local isCharging = status == BatteryManager.BATTERY_STATUS_CHARGING or status == BatteryManager.BATTERY_STATUS_FULL

---Dapatkan penyimpanan yang tersedia
local storage = Environment.getExternalStorageDirectory()
local stat = StatFs(storage.getPath())
local availableBytes = stat.getAvailableBytes()
local availableGB = availableBytes / (1024^3)

---Dapatkan suhu ponsel saat ini
local temperature = batteryIntent.getIntExtra(BatteryManager.EXTRA_TEMPERATURE, 0) / 10

-- Get screen brightness
local brightness = Settings.System.getInt(this.getContentResolver(), Settings.System.SCREEN_BRIGHTNESS)
local brightnessPercent = (brightness / 255) * 100

---Dapatkan status kartu SD
local isMemoryCardInserted = Environment.getExternalStorageState() == Environment.MEDIA_MOUNTED

---Dapatkan nama perangkat
local deviceName = Build.MODEL

---Dapatkan status Bluetooth
local bluetoothAdapter = BluetoothAdapter.getDefaultAdapter()
local bluetoothStatus = bluetoothAdapter and (bluetoothAdapter.isEnabled() and "di aktifkan" or "di nonaktifkan") or "not available"

---Dapatkan status koneksi jaringan
local connectivityManager = this.getSystemService(Context.CONNECTIVITY_SERVICE)
local activeNetworkInfo = connectivityManager.getActiveNetworkInfo()
local isConnected = activeNetworkInfo and activeNetworkInfo.isConnected
local internetStatus = isConnected and "terhubung" or "terputus"

---Dapatkan status mode Pesawat
local isAirplaneModeOn = Settings.System.getInt(this.getContentResolver(), Settings.Global.AIRPLANE_MODE_ON, 0) == 1
local airplaneModeStatus = isAirplaneModeOn and "di aktifkan" or "di nonaktifkan"

---Dapatkan status Lokasi
local locationManager = this.getSystemService(Context.LOCATION_SERVICE)
local isLocationEnabled = locationManager.isProviderEnabled(LocationManager.GPS_PROVIDER)
local locationStatus = isLocationEnabled and "di aktifkan" or "di nonaktifkan"

-- Create and speak the message
local chargingStatusMessage = isCharging and "perangkat sedang mengisi daya." or "perangkat sedang tidak mengisi daya."

local message = "sekarang jam " .. formattedTime ..
                ", tanggal " .. formattedDate ..
                ", tingkat baterai " .. string.format("%.0f", batteryPercent) .. "%" ..
                ", kondisi kesehatan baterai " .. batteryHealth ..
                (isCharging and ". perangkat sedang mengisi daya." or ". perangkat sedang tidak mengisi daya.") ..
                ", penyimpanan yang tersedia " .. string.format("%.2f", availableGB) .. " GB" ..
                ", suhu ponsel saat ini " .. temperature .. "°Celcius" ..
                ", tingkat kecerahan layar " .. string.format("%.0f", brightnessPercent) .. "%" ..
                ", kartu SD " .. (isMemoryCardInserted and "dimasukan" or "tidak dimasukan") ..
                ", nama perangkat " .. deviceName ..
                ", jaringan bluetooth saat ini " .. bluetoothStatus ..
                ", jaringan internet " .. internetStatus ..
                ", mode pesawat" .. airplaneModeStatus ..
                ", lokasi " .. locationStatus

this.speak(message)
return true